# testing widgetsInTemplate support

    			<div>
    				<div dojoAttachPoint="normalNode" >normal node</div>
    				<button dojoAttachPoint="buttonWidget" dojoAttachEvent="onClick:onClick" dojoType="dijit.form.Button">button #1</button>
    				<div dojoAttachPoint="checkboxWidget" dojoAttachEvent="onClick:onClick" dojoType="dijit.form.CheckBox"></div> checkbox #1
    				<div dojoAttachPoint="progressBarWidget" dojoAttachEvent="onChange:onClick" style="width:400px"
    					maximum="200" progress="20" dojoType="dijit.ProgressBar"></div>
    			</div>

    		<div>
    			<div dojoAttachPoint="containerNode" >
    				<div dojoAttachPoint="checkboxWidget" dojoType="dijit.form.CheckBox"></div>
    				checkbox #2
    			</div>
    		</div>

    		<div>
    			<div dojoAttachPoint="checkboxWidget" dojoType="dijit.form.CheckBox"></div> checkbox #3
    			<div dojoAttachPoint="containerNode" ></div>
    		</div>

hello world this is my
and some more

    		<div>
    			<div dojoType="dijit.layout.TabContainer" dojoAttachPoint="tabCont" style="height: 5em;">
    				<div dojoType="dijit.layout.ContentPane" dojoAttachPoint="tab1" title="Tab 1">
    					pane 1
    				</div>
    				<div dojoType="dijit.layout.ContentPane" dojoAttachPoint="tab2" title="Tab 2">
    					pane 2
    				</div>
    			</div>
    		</div>

    		<div>
    			<div dojoType="TestLayoutWidget" dojoAttachPoint="layout">
    				<div dojoType="TestCtndWidget" dojoAttachPoint="layChild1"></div>
    				<div dojoType="TestCtndWidget" dojoAttachPoint="layChild2"></div>
    			</div>
    			<div dojoType="TestCtnrWidget" dojoAttachPoint="container">
    				<div dojoType="TestCtndWidget" dojoAttachPoint="contained1"></div>
    				<div dojoType="TestCtndWidget" dojoAttachPoint="contained2"></div>
    			</div>
    			<div dojoType="TestStubWidget" dojoAttachPoint="stub1"></div>
    			<div dojoType="TestNonCtnrWidget" dojoAttachPoint="nonContainer">
    				<div dojoType="TestStubWidget" dojoAttachPoint="nonContained1"></div>
    				<div dojoType="TestStubWidget" dojoAttachPoint="nonContained2"></div>
    			</div>
    			<div dojoType="TestCtnrWidget" dojoAttachPoint="threeLevel">
    				<div dojoType="TestNonCtnrWidget" dojoAttachPoint="secondLevel">
    					<div dojoType="TestStubWidget" dojoAttachPoint="bottomLevel"></div>
    				</div>
    			</div>
    			<div dojoType="TestNonCtnrWidget" dojoAttachPoint="anotherThree">
    				<div dojoType="TestCtnrWidget" dojoAttachPoint="anotherSecond">
    					<div dojoType="TestCtndWidget" dojoAttachPoint="anotherBottom"></div>
    				</div>
    			</div>
    		</div>